pub struct QuantizationParams {
pub bits: u8,
pub scale: f32,
pub zero_point: i32,
pub min_val: f32,
pub max_val: f32,
pub method: QuantizationMethod,
pub data_type: QuantizedDataType,
pub channel_scales: Option<Vec<f32>>,
pub channel_zero_points: Option<Vec<i32>>,
}Expand description
Parameters for the quantization process
Fields
bits: u8The number of bits used for quantization
scale: f32The scale factor used to convert between quantized and float values For per-channel quantization, this is the default scale for debugging
zero_point: i32The zero point used for asymmetric quantization (for affine quantization) For per-channel quantization, this is the default zero point for debugging
min_val: f32The minimum value of the original data For per-channel quantization, this is across all channels
max_val: f32The maximum value of the original data For per-channel quantization, this is across all channels
method: QuantizationMethodThe quantization method used
data_type: QuantizedDataTypeThe data type used for storage
channel_scales: Option<Vec<f32>>Per-channel scale factors (only used for per-channel quantization)
channel_zero_points: Option<Vec<i32>>Per-channel zero points (only used for per-channel affine quantization)