pub struct SparseMatrixView<T> {
pub rows: usize,
pub cols: usize,
pub indptr: Vec<usize>,
pub indices: Vec<usize>,
pub data: Vec<T>,
}Expand description
A simple view struct for sparse matrices in CSR format
This struct provides a simple interface to view a sparse matrix in CSR format. It is designed to be compatible with the CSR format used in scirs2-sparse.
Fields
rows: usizeNumber of rows
cols: usizeNumber of columns
indptr: Vec<usize>Row pointers (size rows+1)
indices: Vec<usize>Column indices
data: Vec<T>Data values
Implementations