pub struct AdaptiveVectorizationEngine { /* private fields */ }Expand description
Advanced ENHANCEMENT: Adaptive Vectorization Engine with CPU Feature Detection
This system provides runtime detection of CPU capabilities and automatic selection of optimal vectorization strategies for maximum performance.
Implementations
Sourceimpl AdaptiveVectorizationEngine
impl AdaptiveVectorizationEngine
Sourcepub fn select_optimal_strategy(
&self,
matrixsize: (usize, usize),
) -> VectorizationStrategy
pub fn select_optimal_strategy( &self, matrixsize: (usize, usize), ) -> VectorizationStrategy
Select optimal vectorization strategy based on matrix size and CPU features
Sourcepub fn adaptivematrix_multiply_f32(
&mut self,
a: &ArrayView2<'_, f32>,
b: &ArrayView2<'_, f32>,
) -> LinalgResult<Array2<f32>>
pub fn adaptivematrix_multiply_f32( &mut self, a: &ArrayView2<'_, f32>, b: &ArrayView2<'_, f32>, ) -> LinalgResult<Array2<f32>>
Adaptive matrix multiplication with optimal vectorization
Sourcepub fn get_performance_report(&self) -> HashMap<VectorizationStrategy, f64>
pub fn get_performance_report(&self) -> HashMap<VectorizationStrategy, f64>
Get performance report for different strategies
Sourcepub fn set_auto_tuning(&mut self, enabled: bool)
pub fn set_auto_tuning(&mut self, enabled: bool)
Enable or disable auto-tuning